# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.5] - 2025-07-13

### Added

- Add link to commit if PR number isn't in commit message ([`26c3022`](https://github.com/danroc/kacl/commit/26c3022))

## [0.1.4] - 2025-06-18

### Added

- Auto-detect remote URL ([`a40566e`](https://github.com/danroc/kacl/commit/a40566e))

### Changed

- Add README ([`4be5805`](https://github.com/danroc/kacl/commit/4be5805))
- Update dependencies ([`69c17e0`](https://github.com/danroc/kacl/commit/69c17e0))

## [0.1.3] - 2024-12-17

### Added

- Add date to release and force unreleased section ([`282804c`](https://github.com/danroc/kacl/commit/282804c))

### Fixed

- Add "Unreleased" to links ([`3e11e87`](https://github.com/danroc/kacl/commit/3e11e87))

## [0.1.2] - 2024-11-19

### Added

- Keep categories in order (sorted alphabetically) ([`f56b060`](https://github.com/danroc/kacl/commit/f56b060))

## [0.1.1] - 2024-11-19

### Changed

- Only ignore `wip` commits ([`396b275`](https://github.com/danroc/kacl/commit/396b275))

## [0.1.0] - 2024-11-18

### Added

- Initial release ([`230e7e5`](https://github.com/danroc/kacl/commit/230e7e5))

[Unreleased]: https://github.com/danroc/kacl/compare/v0.1.5...HEAD
[0.1.5]: https://github.com/danroc/kacl/compare/v0.1.4...v0.1.5
[0.1.4]: https://github.com/danroc/kacl/compare/v0.1.3...v0.1.4
[0.1.3]: https://github.com/danroc/kacl/compare/v0.1.2...v0.1.3
[0.1.2]: https://github.com/danroc/kacl/compare/v0.1.1...v0.1.2
[0.1.1]: https://github.com/danroc/kacl/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/danroc/kacl/releases/tag/v0.1.0
